# aioairzone-cloud
Python library to control Airzone Cloud devices.

## Requirements
- Python >= 3.10

## Install
```bash
pip install aioairzone-cloud
```

## Install from Source
Run the following command inside this folder
```bash
pip install --upgrade .
```

## Examples
Examples can be found in the `examples` folder
